@@ -1,10 +1,14 @@
 import logging
 import subprocess
 
+from borgmatic.execute import execute_command
 
 logger = logging.getLogger(__name__)
 
 
+INFO_REPOSITORY_NOT_FOUND_EXIT_CODE = 2
+
+
 def initialize_repository(
     repository,
     encryption_mode,
@@ -21,9 +25,13 @@ def initialize_repository(
     info_command = (local_path, 'info', repository)
     logger.debug(' '.join(info_command))
 
-    if subprocess.call(info_command, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL) == 0:
+    try:
+        execute_command(info_command, output_log_level=None)
         logger.info('Repository already exists. Skipping initialization.')
         return
+    except subprocess.CalledProcessError as error:
+        if error.returncode != INFO_REPOSITORY_NOT_FOUND_EXIT_CODE:
+            raise
 
     init_command = (
         (local_path, 'init', repository)
@@ -35,5 +43,5 @@ def initialize_repository(
         + (('--remote-path', remote_path) if remote_path else ())
     )
 
-    logger.debug(' '.join(init_command))
+    # Don't use execute_command() here because it doesn't support interactive prompts.
     subprocess.check_call(init_command)
